Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(413)

Unified Diff: components/web_view/frame_apptest.cc

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/web_view/frame.cc ('k') | components/web_view/frame_connection.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/web_view/frame_apptest.cc
diff --git a/components/web_view/frame_apptest.cc b/components/web_view/frame_apptest.cc
index a8f0bb8c873fa48a748cca049050217adc6b05b3..2b32946cf4bcb21853f8ccc15323af6e613ffb4b 100644
--- a/components/web_view/frame_apptest.cc
+++ b/components/web_view/frame_apptest.cc
@@ -285,7 +285,7 @@ class ViewAndFrame : public mus::WindowTreeDelegate {
class FrameTest : public mojo::test::ApplicationTestBase,
public mojo::ApplicationDelegate,
public mus::WindowTreeDelegate,
- public mojo::InterfaceFactory<mojo::ViewTreeClient>,
+ public mojo::InterfaceFactory<mus::mojom::WindowTreeClient>,
public mojo::InterfaceFactory<mojom::FrameClient> {
public:
FrameTest() : most_recent_connection_(nullptr), window_manager_(nullptr) {}
@@ -353,7 +353,7 @@ class FrameTest : public mojo::test::ApplicationTestBase,
// ApplicationDelegate implementation.
bool ConfigureIncomingConnection(
mojo::ApplicationConnection* connection) override {
- connection->AddService<mojo::ViewTreeClient>(this);
+ connection->AddService<mus::mojom::WindowTreeClient>(this);
connection->AddService<mojom::FrameClient>(this);
return true;
}
@@ -380,8 +380,8 @@ class FrameTest : public mojo::test::ApplicationTestBase,
scoped_ptr<FrameConnection> frame_connection =
CreateFrameConnection(application_impl());
mojom::FrameClient* frame_client = frame_connection->frame_client();
- mojo::ViewTreeClientPtr view_tree_client =
- frame_connection->GetViewTreeClient();
+ mus::mojom::WindowTreeClientPtr view_tree_client =
+ frame_connection->GetWindowTreeClient();
mus::Window* frame_root_view = window_manager()->CreateWindow();
window_manager()->GetRoot()->AddChild(frame_root_view);
frame_tree_.reset(new FrameTree(
@@ -399,10 +399,10 @@ class FrameTest : public mojo::test::ApplicationTestBase,
ApplicationTestBase::TearDown();
}
// Overridden from mojo::InterfaceFactory<mojo::ViewTreeClient>:
void Create(
mojo::ApplicationConnection* connection,
- mojo::InterfaceRequest<mojo::ViewTreeClient> request) override {
+ mojo::InterfaceRequest<mus::mojom::WindowTreeClient> request) override {
if (view_and_frame_) {
mus::WindowTreeConnection::Create(
view_and_frame_.get(), request.Pass(),
@@ -425,7 +425,7 @@ class FrameTest : public mojo::test::ApplicationTestBase,
scoped_ptr<FrameTree> frame_tree_;
scoped_ptr<ViewAndFrame> root_view_and_frame_;
- mojo::ViewTreeHostPtr host_;
+ mus::mojom::WindowTreeHostPtr host_;
// Used to receive the most recent view manager loaded by an embed action.
WindowTreeConnection* most_recent_connection_;
« no previous file with comments | « components/web_view/frame.cc ('k') | components/web_view/frame_connection.h » ('j') | no next file with comments »
@@ -399,10 +399,10 @@ class FrameTest : public mojo::test::ApplicationTestBase,
ApplicationTestBase::TearDown();
}
- // Overridden from mojo::InterfaceFactory<mojo::ViewTreeClient>:
+ // Overridden from mojo::InterfaceFactory<mus::mojom::WindowTreeClient>:
void Create(
mojo::ApplicationConnection* connection,

Powered by Google App Engine
This is Rietveld 408576698